Introduction
============

collective.mcp is a Plone product that helps creating a custom control
panel for the site's users.
mcp stands for Mac Control Panel, as the base theme is inspired by the
Mac OSX control panel.

The goal is not to replace Plone's control panel but to help creating
a new one decidated to the users. This will might be usefull for web
applications based on Plone.

You can see some screenshots of the product at this page:
https://github.com/zestsoftware/collective.mcp/wiki/Screenshots

This product does not magically create the pages for your site, it
only provides some API to create them, as we'll see later in this
README.


Compatibility
=============

This has been tested with Plone 3.3.5.
